Module brackets

Module brackets 

Bracket-pair matching: find the counterpart of a bracket at or near the cursor.

Functions

find_matching_bracket
Returns the positions of a matched bracket pair if the cursor is on or adjacent to a bracket. The first element is the opening bracket, the second is the closing bracket.