current_prefix

Function current_prefix 

pub fn current_prefix(text: &str, cursor: usize) -> String
Returns the run of word characters ending immediately before cursor, where cursor is a character index into text.