pub enum Error {
Read(Error),
Rule(&'static str),
}Expand description
Why a language file could not be read.
Variants
Read(Error)
The file could not be opened or parsed as key-value lines.
Rule(&'static str)
A rule was there but did not have the words it needs.