Crate idet_core

Crate idet_core 

Backend-agnostic editing logic for the text editor: word autocomplete, line moves, word swaps and indentation edits.

Modules

brackets
Bracket-pair matching: find the counterpart of a bracket at or near the cursor.
completion
Word collection and prefix matching for autocomplete.
edits
Text insertion and indentation edits, all character-index based.
lineops
Moving the current line, paragraph or markdown section up or down.
syntax
Syntax highlighting described by a config file, one per language.
wordops
Swapping the word at the cursor with an adjacent word.