pub fn insert(text: &str, cursor: usize, insertion: &str) -> (String, usize)
Inserts insertion at character index cursor, returning the new text and the cursor placed after the inserted text.
insertion
cursor